#
# spec file for package python-ogr
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ogr
Version:        0.50.4
Release:        1.2
Summary:        One API for multiple git forges
License:        MIT
URL:            https://github.com/packit-service/ogr
Source:         https://files.pythonhosted.org/packages/source/o/ogr/ogr-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Deprecated
Requires:       python-GitPython
Requires:       python-PyGithub
Requires:       python-PyYAML
Requires:       python-cryptography
Requires:       python-python-gitlab
Requires:       python-requests
Requires:       python-urllib3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Deprecated}
BuildRequires:  %{python_module GitPython}
BuildRequires:  %{python_module PyGithub}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module flexmock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-gitlab}
BuildRequires:  %{python_module requre}
# /SECTION
%python_subpackages

%description
One API for multiple git forges.

%prep
%autosetup -p1 -n ogr-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/ogr
%{python_sitelib}/ogr-%{version}.dist-info

%changelog
* Wed Feb 12 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.50.4
  * Trigger a new release to confirm the correct SPDX licence.
- Use Python 3.11 on SLE-15 by default
* Wed Jan 22 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.50.3
  * We have improved wrapping of the forge-specific exceptions, string
    representation of the original exception is now included. (#884)
  * The test suite for parsing git URLs has been extended and also the
    handling of GitHub repository with changed owner or name has been
    improved. (#874)
* Fri Nov  8 2024 Nico Krapp <nico.krapp@suse.com>
- Update to 0.50.2:
  * There is a new method for getting a single commit comment,
    supporting also retrieval and adding reactions in GitHub. (#865)
- Update to 0.50.1:
  * We have fixed an issue that caused inconsistencies with the expected
    behavior stated by the documentation when adding duplicate reactions
    to GitLab comments. (#861)
- Update to 0.50.0:
  * A new get_commits method was implemented for GitHub and Gitlab projects. (#857)
  * An issue with silently ignoring error (#760) was fixed. (#855)
- Update to 0.49.2:
  * GitLabProject.get_file_content can now correctly handle file paths
    starting with ./. (#844)
- Update to 0.49.1:
  * Interface for labels was unified and labels property for PullRequest and
    Issue now return list of PRLabel and IssueLabel respectively. (#839)
- Update to 0.49.0:
  * For Pagure there are 2 new methods available: one for getting users with
    specified access rights and one for getting members of a group. (#834)
- Update to 0.48.1:
  * For Pagure there are 2 new methods available: one for getting users with
    specified access rights and one for getting members of a group. (#834)
- Update to 0.48.0:
  * There is a new get_pr_files_diff method supported for Pagure. (#826)
  * We have fixed a bug that GithubRelease.url returned an API URL. (#824)
- Update to 0.47.1:
  * Fixed an issue where getting a list of GitLab merge requests using .list()
    would return only 20 items. (#819)
- Update to 0.47.0:
  * Added support for removing users/groups from a project and possibility
    to check for groups with permissions to modify a PR. (#815)
- Update to 0.46.2:
  * Added missing README to package metadata.
- Update to 0.46.1:
  * Migrated from setup.py + setup.cfg to pyproject.toml with hatchling
    as a build backend and to pyproject macros in the spec file. (#808)
- Update to 0.46.0:
  * We have fixed a bug in get_fork method for Pagure about checking the
    usernames for a match when going through existing forks. (#800)
* Wed Jul 19 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.45.0:
  * OGR now supports PyGithub >= 1.58.
  * OGR now understands a few community-hosted GitLab instances that could
    not be determined automatically from the hostname.
  * Fixes an issue with project->service mapping where the service with an
    url not containing the service type wasn't matched.
  * A bug in ogr resulting in returning only first page of pull requests
    for Pagure has been fixed.
  * ogr now raises `GitForgeInternalError` rather than `PagureAPIException`
    when getting 50x response from the Pagure API.
  * `CommitComment.comment` has been deprecated in favour of
    `CommitComment.body` to make the naming consistent across objects.
  * ogr now requires Python 3.9 or later.
  * Using the method `users_with_write_access` you can generate the set of
    users that have write access to the project and the method
    `has_write_access(user)` you can find out if the user has write access
    to the project.
  * We have implemented the closed_by property for the Pagure pull request
    for getting the login of the account that closed the pull request.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
- Drop BuildRequires on setuptools_scm_git_archive.
* Tue Jun 27 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.45.0
  * OGR now supports PyGithub >= 1.58.
  * OGR now understands a few community-hosted GitLab instances
    that could not be determined automatically from the hostname.
  * Fixes an issue with project->service mapping where the service
    with an url not containing the service type wasn't matched.
  * A bug in ogr resulting in returning only first page of pull
    requests for Pagure has been fixed.
  * ogr now raises GitForgeInternalError rather than PagureAPIException
    when getting 50x response from the Pagure API.
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.41.0
  * CommitComment.comment has been deprecated in favour of CommitComment.body to make the naming consistent across objects. (#748)
  * ogr now requires Python 3.9 or later. (#746)
* Fri Oct 14 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.40.0:
  * Implement the closed_by property for the Pagure pull request for
    getting the login of the account that closed the pull request. (#718)
  * Add users_with_write_access so you can generate the set of users that
    have write access to the project and the method has_write_access(user),
    to query if a user has access.
* Mon Jul  4 2022 Daniel García Moreno <dani@danigm.net>
- Update to v0.38.1
- Remove skip tests
* Wed Nov 18 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v0.18.0
* Mon Jan 20 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.9.0
